<!---
The contents of this file are subject to the Mozilla Public License Version 1.1
(the "License"); you may not use this file except in compliance with the
License. You may obtain a copy of the License at http://www.mozilla.org/MPL/
 
Software distributed under the License is distributed on an "AS IS" basis,
WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for
the specific language governing rights and limitations under the License.
 
The Original Code is comprised of the ADF directory
 
The Initial Developer of the Original Code is
PaperThin, Inc. Copyright(C) 2011.
All Rights Reserved.
 
By downloading, modifying, distributing, using and/or accessing any files
in this directory, you agree to the terms and conditions of the applicable
end user license agreement.
--->

<!---
/* *************************************************************** */
Author: 	
	PaperThin Inc.
	G. Cronkright
Name:
	video_size_calc_render.cfm
Summary:
	CFT to render a video size option fields for the vidoes.
Version:
	1.0.0
History:
	2011-06-11 - GAC - Created
	2011-11-02 - GAC - Added Min and Max width value options
--->
<cfscript>
	// the fields current value
	currentValue = attributes.currentValues[fqFieldName];
	// the param structure which will hold all of the fields from the props dialog
	xparams = parameters[fieldQuery.inputID];

	//--Field Security--
	readOnly = application.ADF.forms.isFieldReadOnly(xparams);
	
	// Validate if the property field has been defined
	if ( NOT StructKeyExists(xparams,"fldID") )
		xparams.fldID = fqFieldName;
	else if ( LEN(TRIM(xparams.fldID)) LTE 0 )
		xparams.fldID = ReplaceNoCase(xParams.fieldName,'fic_','');

	if( NOT structKeyExists(xparams, "maxWidth") )
		xparams.maxWidth = "900";
	if( NOT structKeyExists(xparams, "minWidth") )
		xparams.minWidth = "150";

	// Load the JQuery Plugin Headers
	application.ptSocialMedia.scripts.loadjQuery();
	// Load the header for the CFJS jquery plug-in
	application.ptSocialMedia.scripts.loadCFJS();
	//application.ptSocialMedia.scripts.loadJQueryBBQ();
	//application.ptSocialMedia.scripts.loadJQuerySelectboxes();
</cfscript>

<cfoutput>
	<script>
		// javascript validation to make sure they have text to be converted
		#fqFieldName#=new Object();
		#fqFieldName#.id='#fqFieldName#';
		#fqFieldName#.tid=#rendertabindex#;
		#fqFieldName#.msg="Please select a value for the #xparams.label# field.";
		#fqFieldName#.validator = "validate_#fqFieldName#()";

		//If the field is required
		if ( '#xparams.req#' == 'Yes' ){
			// push on to validation array
			vobjects_#attributes.formname#.push(#fqFieldName#);
		}

		//Validation function
		function validate_#fqFieldName#(){
			if (jQuery("input[name=#fqFieldName#]").val() != ''){
				return true;
			}else{
				return false;
			}
		}

		jQuery( function() {
			jQuery("###xparams.fldID#_FieldErrors").hide();
			
			// If needed, convert currentValue back to values that can popluate the fields 
			<cfif LEN(TRIM(currentValue))>
				// - get the current width,height and aspect ratio 
				// - set the aspect ratio in the drop down
				// - set the width 
				// - set the height
				currentValueWidth = parseVideoWidth_#TRIM(xparams.fldID)#('#currentValue#');
				currentValueHeight = parseVideoHeight_#TRIM(xparams.fldID)#('#currentValue#');
				currentValueAspectRatio = parseAspectRatioStyle_#TRIM(xparams.fldID)#(currentValueWidth,currentValueHeight);

				// Set the aspect ratio in the drop down
				jQuery("###xparams.fldID#_aspectRatio").val(currentValueAspectRatio); 
				jQuery("###xparams.fldID#_playerWidth").val(currentValueWidth);
				jQuery("###xparams.fldID#_playerHeight").text(currentValueHeight);
				//setPlayerHeight_#TRIM(xparams.fldID)#(currentValueAspectRatio,currentValueWidth);
			<cfelse>
				defaultValueWidth = 640;
				jQuery("###xparams.fldID#_playerWidth").val(defaultValueWidth);
				
				// Get the currently selected value
				arFldValue = jQuery("###xparams.fldID#_aspectRatio option:selected").val();
				//widthValue = jQuery("###xparams.fldID#_playerWidth").val();
				//alert(arFldValue);
				setPlayerHeight_#TRIM(xparams.fldID)#(arFldValue,defaultValueWidth);
			</cfif>

			// On KeyUp set the new height and verify max width
			jQuery("###xparams.fldID#_playerWidth").keyup(function (event) {
				var newWidthValue = jQuery(this).val();
				var currARvalue = jQuery("###xparams.fldID#_aspectRatio option:selected").val();
				setPlayerHeight_#TRIM(xparams.fldID)#(currARvalue,newWidthValue);
				// Verify Field Values
				checkForValidFieldEntries_#TRIM(xparams.fldID)#()
			});
			
			jQuery("###xparams.fldID#_aspectRatio").change(function() {
				var selectedARvalue = jQuery(this).val();
				var currWidthValue = jQuery("###xparams.fldID#_playerWidth").val();
				//alert(selectedARvalue);
				setPlayerHeight_#TRIM(xparams.fldID)#(selectedARvalue,currWidthValue);
				// Verify Field Values
				checkForValidFieldEntries_#TRIM(xparams.fldID)#()
			});
			
			// Field validation function
			function checkForValidFieldEntries_#TRIM(xparams.fldID)#() {
				var msg0 = "";
				var msg1 = "";
				var errMsg = '';
				var minWidth = "#xparams.minWidth#";
				var maxWidth = "#xparams.maxWidth#";
				var verifyWidthValue = jQuery("###xparams.fldID#_playerWidth").val();
				var varifyARvalue = jQuery("###xparams.fldID#_aspectRatio option:selected").val();
				
				// Check for a min width
				if ( !verifyWidthValue.length || verifyWidthValue < minWidth ) {
					msg0 = "Player width must be at least " + minWidth + "px";
					msg0 = '<li>' + msg0 + '</li>';
					//alert(msg0);
				}
				// Check for a max width
				if ( verifyWidthValue > maxWidth ) {
					msg1 = "Player width must not be greater than " + maxWidth + "px";
					msg1 = '<li>' + msg1 + '</li>';
					//alert(msg1);
					jQuery("###xparams.fldID#_playerHeight").text('0');
					//jQuery("###xparams.fldID#_playerWidth").val(640);
					//setPlayerHeight_#TRIM(xparams.fldID)#(varifyARvalue,640);
				}
				// Build error Messages
				errMsg = msg0 + msg1;
				
				// Display error messages and disable submit button
				if ( errMsg.length ) {
					// Remove the invalid value from the hidden field
					jQuery("###xparams.fldID#").val('');
					// Generate Error message on near the field
					errMsg = '<ul>' + errMsg + '</ul>';	
					jQuery("###xparams.fldID#_FieldErrors").show('slow').html(errMsg);
					showHideSubmitButtons_#TRIM(xparams.fldID)#('hide');
					lbResizeWindow();
				} else {
					jQuery("###xparams.fldID#_FieldErrors").html('').hide();
					showHideSubmitButtons_#TRIM(xparams.fldID)#('show');
				}
			}
			
			function setPlayerHeight_#TRIM(xparams.fldID)#(aspectRatio,vWidth) {
				var vHeight = 0;
				var vSizeStr = '';
				if ( aspectRatio == 'widescreen' ) {	
					vHeight = getHeight_#TRIM(xparams.fldID)#(vWidth,16,9); 	
				} else {
					vHeight = getHeight_#TRIM(xparams.fldID)#(vWidth,4,3); 		
				}
				jQuery("###xparams.fldID#_playerHeight").text(vHeight);
				vSizeStr = buildVideoSizeStr_#TRIM(xparams.fldID)#(vWidth,vHeight);
				jQuery("###xparams.fldID#").val(vSizeStr);	
			}
			
			function getHeight_#TRIM(xparams.fldID)#(newWidth,orginalWidth,originalHeight) {
				if(orginalWidth == 0)return newWidth;
				var aspectRatio = orginalWidth / originalHeight;
				return Math.round(newWidth / aspectRatio);
			}
			/* function getWidth(newHeight,orginalWidth,originalHeight) {
				if(originalHeight == 0)return newHeight;
				var aspectRatio = orginalWidth / originalHeight;
				return Math.round(newHeight * aspectRatio);
			} */
			function buildVideoSizeStr_#TRIM(xparams.fldID)#(vWidth,vHeight) {
				if ( vWidth.length == 0 ){
					vWidth = 0;
				}
				var vSizeStr = vWidth + 'x' + vHeight;
				return vSizeStr;
			}
			function parseVideoHeight_#TRIM(xparams.fldID)#(vSizeStr) {
				var vHeight = jQuery.ListLast(vSizeStr,"x");
				return vHeight;
			}
			function parseVideoWidth_#TRIM(xparams.fldID)#(vSizeStr) {
				var vWidth = jQuery.ListFirst(vSizeStr,"x");
				return vWidth;
			}
			function parseAspectRatioStyle_#TRIM(xparams.fldID)#(vWidth,vHeight) {
				//var vWidth = parseVideoWidth_#TRIM(xparams.fldID)#(vSizeStr);
				//var vHeight = parseVideoWidth_#TRIM(xparams.fldID)#(vSizeStr);
				var aspectRatioStr = 'standard';
				var aspectRatio = (vWidth / vHeight);
				var arWide = aspectRatio * 9;
				var arStandard = aspectRatio * 3;
				if ( arWide == 16 ) {
					aspectRatioStr = 'widescreen';			
				} else if ( arStandard == 4 ) {
					aspectRatioStr = 'standard';					
				}
				return aspectRatioStr;
			}
			
			// Deal with the Submit buttons
			function showHideSubmitButtons_#TRIM(xparams.fldID)#(status) {
				if ( status == 'hide' ) {
					// Hide CS5 style submit button
					jQuery('input[name="submitbutton"]').hide();
					// Hide the CS6 footer buttons
					jQuery("##clsProxyButtonHolder").hide();
					var sButton = jQuery('input[name="submitbutton"]').attr('disabled','disabled');
						//sButton.unbind();
						sButton.addClass('ui-state-disabled');
				} else if ( status == 'show') {
					// Show CS5 style submit button
					jQuery('input[name="submitbutton"]').show();
					// Show the CS6 footer buttons
					jQuery("##clsProxyButtonHolder").show();
					var sButton = jQuery('input[name="submitbutton"]').removeAttr('disabled');
						//sButton.bind();
						sButton.removeClass('ui-state-disabled');
				}
			}
		});	
	</script>
	
	<style>
		###xparams.fldID#_FieldErrors {
			display: none;
		}
		###xparams.fldID#_FieldErrors ul {
			margin: 0 0 0 0;
			padding: 2px 0 0 0;
		}
		###xparams.fldID#_FieldErrors ul li {
			font-size: 10px;
			color: red;
			list-style-image: none;
			list-style-type: none;
			margin: 0 0 0 0;
			padding: 0 0 0 0;
		}
		
		###xparams.fldID#_calcBox {
			font-size: 11px;
		}
	</style>
	
<!---
	This version is using the wrapFieldHTML functionality, what this does is it takes
	the HTML that you want to put into the TD of the right section of the display, you
	can optionally disable this by adding the includeLabel = false (fourth parameter)
	when false it simply creates a TD and puts your content inside it. This wrapper handles
	everything from description to simple form field handling.
--->

	<cfsavecontent variable="inputHTML">
		<cfoutput>
			<div id='#xparams.fldID#_calcBox'>
				Aspect&nbsp;ratio: 
		        <select id="#xparams.fldID#_aspectRatio" name="#fqFieldName#_aspectRatio">
		            <option value="widescreen">16x9</option>
		            <option value="standard">4x3</option>
		        </select> | 
		        Width:
		        <input id="#xparams.fldID#_playerWidth" size="3" value="" type="text"> | 
		        Height: 
		        <span id="#xparams.fldID#_playerHeight"></span>
			
				<div id="#xparams.fldID#_FieldErrors"></div>
			</div>
			<!--- // hidden field to store the value --->
			<input type='hidden' name='#fqFieldName#' id='#xparams.fldID#' value='#currentValue#'>
		</cfoutput>
	</cfsavecontent>
	#application.ADF.forms.wrapFieldHTML(inputHTML,fieldQuery,attributes)#
	
</cfoutput>